 // Library for Nokia LCD 5110 using PCD5544 driver 

#include <LPC214x.h>
#include "PCD8544.h"


//initializes SPI for transferring data to the controller
//pins 5 and 9 are used as GPIO pins and connects to the following
// 5 -> data/command |  9-> reset  
 void SPI_init()
 {  
 	//configure the pin connect block
 	PINSEL0 = 0x00001100;   
 	
 	//GPIO pins for data/command and reset
 	IODIR0 |= 0x000002A0;	//Output configuration
    	
 	//clock divide of 8 for maximum SPI speed
 	S0SPCCR = 8;			
 	
 	// Control register configurations
 	S0SPCR = 0x0038;      
  }


//writes the byte parameter to location decided by X,Y address pointers
void PCD8544_write(unsigned char byte)
{
	IOCLR0 = SPI_SSEL; 			//SSEL low to enable device
	S0SPDR = byte;				//writes byte
	while(!(S0SPSR&(0x80)));	//checks SPIF bit for transfer completion
	IOSET0 = SPI_SSEL;			//SSEL high to stop transmission
}

//initializes the PCD5544 driver
void PCD8544_init()
{
	IOCLR0 = PCD8544_RESET;		//active low reset to initialize the device

	SPI_init(); 				//initialize the SPI on board

	IOSET0 = PCD8544_RESET;		//Reset disabled

	IOCLR0 = PCD8544_DC;		//D/C low to send commands
	//Sending commands
	PCD8544_write(PCD8544_FUNCTIONSET | PCD8544_EXTENDEDINSTRUCTION);	//To use extended instruction set  
	PCD8544_write(PCD8544_SETVOP | PCD8544_CONTRAST);	//sets operating voltage value Vop       
	PCD8544_write(PCD8544_SETTEMP | PCD8544_TEMP);		//sets temperature coefficient to 3       
	PCD8544_write(PCD8544_SETBIAS | PCD8544_BIAS);	// Bias value set to 3 (depends on multiplex rate) 
	PCD8544_write(PCD8544_FUNCTIONSET);	//to use basic instruction set    
	PCD8544_write(PCD8544_DISPLAYCONTROL | PCD8544_DISPLAYNORMAL);		//This is 8+4 which sets display configuration to normal mode
	//Change this to test LCD
}

//goto function to set address counters to X and Y.
void PCD8544_gotoXY(unsigned char x, unsigned char y)
{
	IOCLR0 = PCD8544_DC;		//command mode
	PCD8544_write(128+x);		//sets X address
	PCD8544_write(64+y);		//sets Y address
}


//clear screen functions to clear lcd and zero out  the RAM
void PCD8544_cls()
{
	int i;
	IOCLR0 = PCD8544_DC;			//command mode
	PCD8544_gotoXY(0,0);			
	IOSET0 = PCD8544_DC;			//data mode
	for(i=0; i<504;i++)
		PCD8544_write(0x00);
}



